#
# spec file for package octave-forge-optim
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  optim
Name:           octave-forge-%{octpkg}
Version:        1.6.2
Release:        1.10
Summary:        Non-linear optimization toolkit for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/optim/index.html
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  blas-devel
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 3.6.0
Requires:       octave-forge-parallel >= 3.0.4
Requires:       octave-forge-statistics
Requires:       octave-forge-struct >= 1.0.12

%description
Non-linear optimization toolkit.
This is part of the Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.2:
  * `nonlin_min', `nonlin_residmin', `nonlin_curvefit',
    `residmin_stat', `curvefit_stat': Fix new Octave versions
    throw an error if a user function which doesn't use
    'varargin' is called with more arguments than it explicitly
    accepts.
  * Removed deprecated function `nmsmax' -- the same code is in
    `fminsearch' in core Octave, with a slightly different
    interface.
  * Deprecated frontend function `fmins'.
  * Renamed `expfit' to `pronyfit'. Calling it with `expfit(...)'
    still works, but is deprecated.
  * Various bug fixes and build fixes for current development
    version 8.0 of Octave.
* Sat Mar 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.1:
  * Bug fixes: `__qp__' invocation in `quadprog' (and so
    `lsqlin'), handling of combined linear and non-linear
    constraints, handling 'fixed' parameters in `residmin_stat'.
  * `fmincon': Handle bound vectors which are too short as in
    Matlab.
* Tue Jul 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * Build fixes for Octave 5.1 and some bug fixes.
  * With Octave from version 5.1 on, a parallel cluster established
    with package `parallel' can be used for computation of gradients
    with option `parallel_net'.
  * Compatibility frontend `fmincon' has been added.
  * `lsqnonlin' and `lsqcurvefit' now accept a problem structure as
    single argument for compatibility.
  * LinearRegression:
  - Corrected errors in computing variances of data and
    parameters.
  - Erroneous documentation of the 2nd output (`e_var',
    variances of data) has been fixed.
  - The 5th output (previously `y_var'), which was erroneously
    documented as the variances of dependent variables, has been
    replaced by `fit_var', the variances of computed function
    values.
  * Removed deprecated function `samin'. The functionality is
    available with the `samin' backend of function `nonlin_min'.
- Drop add_missing_iostream_include.patch: fixed in upstream
  sources.
* Fri Mar 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix compilation error due to missing iostream.h include
  Add add_missing_iostream_include.patch
- Corrected Url: tag
* Fri Aug 17 2018 badshah400@gmail.com
- Update to version 1.5.3:
  * Added dependency on statistics package.
  * Some bug fixes and build fixes for Octave 4.4.
  * Unit test for nlinfit is now reproducible.
  * Added unit tests in nonlin_residmin and nonlin_curvefit.
  * Default algorithm of `nonlin_min' is now more robust.
  * Standalone function `samin' is deprecated. The functionality
    has been moved into a `samin' backend of function
    `nonlin_min'.
- Drop optim-gcc-warnings.patch: incorporated upstream.
* Mon Oct 31 2016 dmitry_r@opensuse.org
- Update to version 1.5.2
  * Builds with Octave 4.2.
  * Links to core Octave documentation work now in html version of
    package documentation.
  * Fixed treatment of one-parameter-functions in `jacobs'.
  * The sign of `lambda' returned for equality constraints by
    `quadprog' has been changed for compatibility with Matlab.
  * Deprecated `nmsmax' -- the same code is in `fminsearch' in core
    Octave, with a slightly different interface.
  * Fixed bug which could break building oct-files.
- Fix GCC warnings
  * optim-gcc-warnings.patch
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 1.5.0
  * Compatible with Octaves new exception-based error
    handling.
  * New compatibility wrapper functions 'lsqnonlin' and 'lsqcurvefit',
    calling the more general functions 'nonlin_residmin' and
    'nonlin_curvefit' iternally.
  * New compatibility wrapper function 'nlinfit', calling
    'nonlin_curvefit' and 'curvefit_stat' internally. New functions
    'statset' and 'statget' for compatibility in handling options of
    'nlinfit'.
  * New common frontend option 'TypicalX'. Additional common frontend
    options 'FinDiffRelStep' and 'FinDiffType', to match usual option
    names. 'diffp' and 'diff_onesided' are still available and can now
    also be specified as scalars.
  * nonlin_residmin and nonlin_curvefit return determined Lagrange
    multipliers of any constaints
  * New interface function 'quadprog', similar to Octaves 'qp'.
  * New function 'lsqlin'.
  * Removed deprecated functions 'minimize', 'd2_min', and
    'fmin'. Removed obsolete documentation 'optim-mini-howto-2'.
- Drop obsolete:
  * optim-gcc-errors.patch
  * optim-no-doc-rebuild.patch
* Fri Mar 13 2015 dmitry_r@opensuse.org
- Update to version 1.4.1
  * Made compatible with Octave 4.0.
  * Fixed bug #43699.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 1.4.0
- Fix no-return-in-nonvoid-function
  * optim-gcc-errors.patch
- Disable documentation rebuild
  * optim-no-doc-rebuild.patch
